@@ -68,6 +68,30 @@ INDENT: str = " " * INDENT_LENGTH
 lru_cache: Callable[[Callable[..., Any]], Any] = functools.lru_cache
 
 
+def _append_exception_text(error: Exception, message: str) -> None:
+    """
+    Cause `message` to be appended to an error's exception text.
+    """
+    last_attribute_name: str
+    repr_last_attribute_value: str
+    for last_attribute_name in ("strerror", "msg"):
+        last_attribute_value = getattr(error, last_attribute_name, "")
+        if last_attribute_value:
+            setattr(
+                error, last_attribute_name, f"{last_attribute_value}{message}"
+            )
+            break
+    if not last_attribute_value:
+        index: int
+        arg: Any
+        reversed_args: List[Any] = list(reversed(error.args)) or [""]
+        for index, value in enumerate(reversed_args):
+            if isinstance(value, str):
+                reversed_args[index] = f"{value}{message}"
+                break
+        error.args = tuple(reversed(reversed_args))
+
+
 def split_requirement_version_specifiers(requirement: str) -> List[str]:
     """
     >>> split_requirement_version_specifiers(
@@ -852,9 +876,15 @@ def get_distribution_requirement_names(
         extras = tuple(sorted(set(extras or ())))
     if not isinstance(exclude, tuple):
         exclude = tuple(sorted(exclude or ()))
-    return _get_distribution_requirement_names(
-        name, extras=extras, exclude=exclude
-    )
+    try:
+        return _get_distribution_requirement_names(
+            name, extras=extras, exclude=exclude
+        )
+    except KeyError as error:
+        _append_exception_text(
+            error, f"' encountered while looking up requirements for '{name}'"
+        )
+        raise error
 
 
 @lru_cache()
@@ -862,7 +892,7 @@ def _get_distribution_requirement_names(
     name: str,
     extras: Tuple[str, ...] = (),
     exclude: Tuple[str, ...] = (),
-    parallelize: bool = True,
+    parallelize: bool = False,
 ) -> Set[str]:
     exclude_set = set(map(canonicalize_name, exclude))
     # Extract any extras passed as part of the package identifier
